@@ -8,7 +8,6 @@ import (
 	"fmt"
 	"hash"
 	"io"
-	"io/ioutil"
 	"log"
 	"math/rand"
 	"os"
@@ -27,12 +26,6 @@ import (
 	"github.com/olekukonko/tablewriter"
 )
 
-func openTruncate(out string) (*os.File, error) {
-	base := filepath.Dir(out)
-	_ = os.MkdirAll(base, os.ModePerm)
-	return os.OpenFile(out, os.O_TRUNC|os.O_WRONLY|os.O_CREATE, os.ModePerm)
-}
-
 func resolveContentType(fileExtensionOrContentType string) runner.MimeType {
 	if strings.Contains(fileExtensionOrContentType, string(filepath.Separator)) {
 		return runner.MimeType(fileExtensionOrContentType)
@@ -464,7 +457,7 @@ Examples:
     $ dsq testdata/join/users.csv testdata/join/ages.json \
           "select {0}.name, {1}.age from {0} join {1} on {0}.id = {1}.id"
 
-See the repo for more details: https://github.com/multiprocessio/dsq.`
+See the repo for more details: https://github.com/multiprocessio/dsq`
 
 func _main() error {
 	rand.Seed(time.Now().UnixNano())
@@ -488,7 +481,7 @@ func _main() error {
 	// Grab from stdin into local file
 	mimetypeOverride := map[string]string{}
 	if args.pipedMimetype != "" {
-		pipedTmp, err := ioutil.TempFile("", "dsq-stdin")
+		pipedTmp, err := os.CreateTemp("", "dsq-stdin")
 		if err != nil {
 			return err
 		}
@@ -538,7 +531,7 @@ func _main() error {
 			args.cacheSettings.Enabled = false
 		}
 	} else {
-		projectTmp, err := ioutil.TempFile("", "dsq-project")
+		projectTmp, err := os.CreateTemp("", "dsq-project")
 		if err != nil {
 			return err
 		}
@@ -587,7 +580,7 @@ func _main() error {
 	// Check if we can use direct SQLite writer
 	useSQLiteWriter := !args.noSQLiteWriter && !args.schema && !justDumpResults
 	if useSQLiteWriter && !args.cacheSettings.Enabled {
-		tmp, err := ioutil.TempFile("", "dsq-sqlite-shared")
+		tmp, err := os.CreateTemp("", "dsq-sqlite-shared")
 		if err != nil {
 			return err
 		}
